searchData={"items":[{"type":"module","title":"PasswordValidator","doc":"Primary interface to PasswordValidator. The two main methods are `validate/3`\nand `validate_password/2`.","ref":"PasswordValidator.html"},{"type":"module","title":"Examples - PasswordValidator","doc":"iex> opts = [\n    ...>   length: [max: 6],\n    ...> ]\n    iex> PasswordValidator.validate_password(\"too_long\", opts)\n    {:error, [\"String is too long. 8 but maximum is 6\"]}\n\n    iex> opts = [\n    ...>   length: [min: 5, max: 30],\n    ...>   character_set: [\n    ...>     lower_case: 1,  # at least one lower case letter\n    ...>     upper_case: [3, :infinity], # at least three upper case letters\n    ...>     numbers: [0, 4],  # at most 4 numbers\n    ...>     special: [0, 0],  # no special characters allowed\n    ...>   ]\n    ...> ]\n    iex> changeset = Ecto.Changeset.change({%{password: \"Simple_pass12345\"}, %{}}, %{})\n    iex> changeset = PasswordValidator.validate(changeset, :password, opts)\n    iex> changeset.errors\n    [password: {\"Too many special (1 but maximum is 0)\", [\n      {:validator, PasswordValidator.Validators.CharacterSetValidator},\n      {:error_type, :too_many_special}\n    ]},\n    password: {\"Too many numbers (5 but maximum is 4)\", [\n      {:validator, PasswordValidator.Validators.CharacterSetValidator},\n      {:error_type, :too_many_numbers}\n    ]},\n    password: {\"Not enough upper_case characters (only 1 instead of at least 3)\", [\n      {:validator, PasswordValidator.Validators.CharacterSetValidator},\n      {:error_type, :too_few_upper_case}\n    ]}]","ref":"PasswordValidator.html#module-examples"},{"type":"function","title":"PasswordValidator.validate/3","doc":"","ref":"PasswordValidator.html#validate/3"},{"type":"function","title":"PasswordValidator.validate_password/2","doc":"","ref":"PasswordValidator.html#validate_password/2"},{"type":"module","title":"PasswordValidator.Utils","doc":"","ref":"PasswordValidator.Utils.html"},{"type":"function","title":"PasswordValidator.Utils.collect_errors/1","doc":"","ref":"PasswordValidator.Utils.html#collect_errors/1"},{"type":"function","title":"PasswordValidator.Utils.ok_or_errors/1","doc":"","ref":"PasswordValidator.Utils.html#ok_or_errors/1"},{"type":"behaviour","title":"PasswordValidator.Validator","doc":"Specifies the behaviour needed to implement a custom (or built-in) validator.","ref":"PasswordValidator.Validator.html"},{"type":"type","title":"PasswordValidator.Validator.error_info/0","doc":"","ref":"PasswordValidator.Validator.html#t:error_info/0"},{"type":"function","title":"PasswordValidator.Validator.return_errors_or_ok/1","doc":"","ref":"PasswordValidator.Validator.html#return_errors_or_ok/1"},{"type":"function","title":"PasswordValidator.Validator.return_errors_or_ok_old/1","doc":"","ref":"PasswordValidator.Validator.html#return_errors_or_ok_old/1"},{"type":"callback","title":"PasswordValidator.Validator.validate/2","doc":"Validate the given string and return `:ok` or `{:error, errors}` where\n`errors` is a list.","ref":"PasswordValidator.Validator.html#c:validate/2"},{"type":"module","title":"PasswordValidator.Validators.CharacterSetValidator","doc":"Validates a password by checking the different types of characters contained\nwithin.","ref":"PasswordValidator.Validators.CharacterSetValidator.html"},{"type":"function","title":"PasswordValidator.Validators.CharacterSetValidator.do_validate_character_set/3","doc":"","ref":"PasswordValidator.Validators.CharacterSetValidator.html#do_validate_character_set/3"},{"type":"function","title":"PasswordValidator.Validators.CharacterSetValidator.interpret_additional_info/2","doc":"","ref":"PasswordValidator.Validators.CharacterSetValidator.html#interpret_additional_info/2"},{"type":"function","title":"PasswordValidator.Validators.CharacterSetValidator.validate/2","doc":"Example config\n[\n  character_set: [\n    # Require at least 1 upper case letter\n    upper_case: [1, :infinity],\n    # Require at least 1 lower case letter\n    lower_case: 1,\n    # Require at least 1 number\n    numbers: 1,\n    # Require exactly 0 special characters\n    special: [0, 0],\n    # Specify which special characters are allowed (default is :all)\n    allowed_special_characters: \"!@#$%^&*()\",\n  ]\n]","ref":"PasswordValidator.Validators.CharacterSetValidator.html#validate/2"},{"type":"function","title":"PasswordValidator.Validators.CharacterSetValidator.validate_character_set/3","doc":"","ref":"PasswordValidator.Validators.CharacterSetValidator.html#validate_character_set/3"},{"type":"module","title":"PasswordValidator.Validators.CharacterSetValidator.Config","doc":"","ref":"PasswordValidator.Validators.CharacterSetValidator.Config.html"},{"type":"function","title":"PasswordValidator.Validators.CharacterSetValidator.Config.from_options/1","doc":"","ref":"PasswordValidator.Validators.CharacterSetValidator.Config.html#from_options/1"},{"type":"type","title":"PasswordValidator.Validators.CharacterSetValidator.Config.keys/0","doc":"","ref":"PasswordValidator.Validators.CharacterSetValidator.Config.html#t:keys/0"},{"type":"type","title":"PasswordValidator.Validators.CharacterSetValidator.Config.t/0","doc":"","ref":"PasswordValidator.Validators.CharacterSetValidator.Config.html#t:t/0"},{"type":"module","title":"PasswordValidator.Validators.LengthValidator","doc":"Validates a password by checking the length of the password.","ref":"PasswordValidator.Validators.LengthValidator.html"},{"type":"function","title":"PasswordValidator.Validators.LengthValidator.validate/2","doc":"Validate the password by checking the length\n\nExample config (min 5 characters, max 9 characters):\n```\n[\n  length: [\n    min: 5,\n    max: 9,\n  ]\n]\n```","ref":"PasswordValidator.Validators.LengthValidator.html#validate/2"},{"type":"function","title":"Examples - PasswordValidator.Validators.LengthValidator.validate/2","doc":"iex> LengthValidator.validate(\"simple2\", [length: [min: 3]])\n    :ok\n\n    iex> LengthValidator.validate(\"too_short\", [length: [min: 10]])\n    {:error, [{\"String is too short. Only 9 characters instead of 10\",\n    validator: PasswordValidator.Validators.LengthValidator, error_type: :too_short}]}\n\n    iex> LengthValidator.validate(\"too_long\", [length: [min: 3, max: 6]])\n    {:error, [{\"String is too long. 8 but maximum is 6\",\n    validator: PasswordValidator.Validators.LengthValidator, error_type: :too_long}]}","ref":"PasswordValidator.Validators.LengthValidator.html#validate/2-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"0.5.2 (2025-04-12) - Changelog","doc":"Housekeeping:\n* Update deps, docs and CI\n* Test on Elixir 1.18 and Erlang/OTP 27","ref":"changelog.html#0-5-2-2025-04-12"},{"type":"extras","title":"0.5.1 (2024-07-14) - Changelog","doc":"Housekeeping:\n* Update deps, docs and CI\n* Fix dialyzer issues","ref":"changelog.html#0-5-1-2024-07-14"},{"type":"extras","title":"0.5.0 (2023-05-14) - Changelog","doc":"**Potentially Breaking Changes**\n* Return additional information with the errors on changesets\n  * This generally shouldn't break anything, but if the code is using\n    `Ecto.Changeset.traverse_errors/2` and looking at the `additional_info` it could.\n\nImprovements:\n* Add the ability to customize error messages by passing `messages` to a validator\n\nHousekeeping:\n* Update deps and docs\n* Fix deprecation warning","ref":"changelog.html#0-5-0-2023-05-14"},{"type":"extras","title":"0.4.1 (2020-11-11) - Changelog","doc":"* Bump dependencies used for development and testing\n* No user-visible changes","ref":"changelog.html#0-4-1-2020-11-11"},{"type":"extras","title":"0.4.0 (2019-09-02) - Changelog","doc":"**Breaking Changes**\n* Extract `PasswordValidator.Validators.ZXCVBNValidator` to a separate (compatible) repository: https://github.com/axelson/password-validator-zxcvbn\n* Increased minimum Elixir version to 1.7\n  * Please file an issue if this is too high","ref":"changelog.html#0-4-0-2019-09-02"},{"type":"extras","title":"0.3.0 (2019-04-05) - Changelog","doc":"* Fix: Use a better exception message for invalid length validator configurations\n* Feature: Add support for zxcvbn via https://github.com/techgaun/zxcvbn-elixir\n  * Adds zxcvbn as a dependency\n  * Enabled by default (use `[zxcvbn: :disabled]` to disable**\n* Fix: Bump dev dependencies\n\n**Breaking Changes**\n* `PasswordValidator.Validators.ZXCVBNValidator` is enabled by default (with a\n  minimum score of 2) which in many ways is more strict than the existing\n  validators.\n  * Pass `[zxcvbn: :disabled]` to disable ZXCVBNValidator. e.g.\n    `PasswordValidator.validate_password(\"some password\", zxcvbn: :disabled)`","ref":"changelog.html#0-3-0-2019-04-05"},{"type":"extras","title":"0.2.1 (2019-01-23) - Changelog","doc":"* Fix compilation warning on Elixir 1.8\n** https://github.com/axelson/password-validator/pull/3\n* Update dependencies","ref":"changelog.html#0-2-1-2019-01-23"},{"type":"extras","title":"0.2.0 (2018-03-19) - Changelog","doc":"* Handle the case when a nil password is passed in\n** https://github.com/axelson/password-validator/pull/1\n* Update internal dependencies\n\nPotentially breaking changes:\n* Update formatting of returned errors\n** https://github.com/axelson/password-validator/pull/1","ref":"changelog.html#0-2-0-2018-03-19"},{"type":"extras","title":"0.1.2 (2017-07-31) - Changelog","doc":"* Add a missing typespec and this changelog","ref":"changelog.html#0-1-2-2017-07-31"},{"type":"extras","title":"0.1.1 (2017-07-31) - Changelog","doc":"* Doc fixes\n* Upgrade elixir and dependencies","ref":"changelog.html#0-1-1-2017-07-31"},{"type":"extras","title":"0.1.0 (2017-07-31) - Changelog","doc":"* Initial public release 🎉","ref":"changelog.html#0-1-0-2017-07-31"},{"type":"extras","title":"License","doc":"# Apache License\nVersion 2.0, January 2004\n\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION","ref":"license.html"},{"type":"extras","title":"1. Definitions. - License","doc":"\"License\" shall mean the terms and conditions for use, reproduction, and\ndistribution as defined by Sections 1 through 9 of this document.\n\n\"Licensor\" shall mean the copyright owner or entity authorized by the copyright\nowner that is granting the License.\n\n\"Legal Entity\" shall mean the union of the acting entity and all other entities\nthat control, are controlled by, or are under common control with that entity.\nFor the purposes of this definition, \"control\" means (i) the power, direct or\nindirect, to cause the direction or management of such entity, whether by\ncontract or otherwise, or (ii) ownership of fifty percent (50%) or more of the\noutstanding shares, or (iii) beneficial ownership of such entity.\n\n\"You\" (or \"Your\") shall mean an individual or Legal Entity exercising\npermissions granted by this License.\n\n\"Source\" form shall mean the preferred form for making modifications, including\nbut not limited to software source code, documentation source, and configuration\nfiles.\n\n\"Object\" form shall mean any form resulting from mechanical transformation or\ntranslation of a Source form, including but not limited to compiled object code,\ngenerated documentation, and conversions to other media types.\n\n\"Work\" shall mean the work of authorship, whether in Source or Object form, made\navailable under the License, as indicated by a copyright notice that is included\nin or attached to the work (an example is provided in the Appendix below).\n\n\"Derivative Works\" shall mean any work, whether in Source or Object form, that\nis based on (or derived from) the Work and for which the editorial revisions,\nannotations, elaborations, or other modifications represent, as a whole, an\noriginal work of authorship. For the purposes of this License, Derivative Works\nshall not include works that remain separable from, or merely link (or bind by\nname) to the interfaces of, the Work and Derivative Works thereof.\n\n\"Contribution\" shall mean any work of authorship, including the original version\nof the Work and any modifications or additions to that Work or Derivative Works\nthereof, that is intentionally submitted to Licensor for inclusion in the Work\nby the copyright owner or by an individual or Legal Entity authorized to submit\non behalf of the copyright owner. For the purposes of this definition,\n\"submitted\" means any form of electronic, verbal, or written communication sent\nto the Licensor or its representatives, including but not limited to\ncommunication on electronic mailing lists, source code control systems, and\nissue tracking systems that are managed by, or on behalf of, the Licensor for\nthe purpose of discussing and improving the Work, but excluding communication\nthat is conspicuously marked or otherwise designated in writing by the copyright\nowner as \"Not a Contribution.\"\n\n\"Contributor\" shall mean Licensor and any individual or Legal Entity on behalf\nof whom a Contribution has been received by Licensor and subsequently\nincorporated within the Work.","ref":"license.html#1-definitions"},{"type":"extras","title":"2. Grant of Copyright License. - License","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable copyright license to reproduce, prepare Derivative Works of,\npublicly display, publicly perform, sublicense, and distribute the Work and such\nDerivative Works in Source or Object form.","ref":"license.html#2-grant-of-copyright-license"},{"type":"extras","title":"3. Grant of Patent License. - License","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable (except as stated in this section) patent license to make, have\nmade, use, offer to sell, sell, import, and otherwise transfer the Work, where\nsuch license applies only to those patent claims licensable by such Contributor\nthat are necessarily infringed by their Contribution(s) alone or by combination\nof their Contribution(s) with the Work to which such Contribution(s) was\nsubmitted. If You institute patent litigation against any entity (including a\ncross-claim or counterclaim in a lawsuit) alleging that the Work or a\nContribution incorporated within the Work constitutes direct or contributory\npatent infringement, then any patent licenses granted to You under this License\nfor that Work shall terminate as of the date such litigation is filed.","ref":"license.html#3-grant-of-patent-license"},{"type":"extras","title":"4. Redistribution. - License","doc":"You may reproduce and distribute copies of the Work or Derivative Works thereof\nin any medium, with or without modifications, and in Source or Object form,\nprovided that You meet the following conditions:\n\n1. You must give any other recipients of the Work or Derivative Works a copy of\n   this License; and\n\n2. You must cause any modified files to carry prominent notices stating that\n   You changed the files; and\n\n3. You must retain, in the Source form of any Derivative Works that You\n   distribute, all copyright, patent, trademark, and attribution notices from\n   the Source form of the Work, excluding those notices that do not pertain to\n   any part of the Derivative Works; and\n\n4. If the Work includes a \"NOTICE\" text file as part of its distribution, then\n   any Derivative Works that You distribute must include a readable copy of the\n   attribution notices contained within such NOTICE file, excluding those\n   notices that do not pertain to any part of the Derivative Works, in at least\n   one of the following places: within a NOTICE text file distributed as part\n   of the Derivative Works; within the Source form or documentation, if\n   provided along with the Derivative Works; or, within a display generated by\n   the Derivative Works, if and wherever such third-party notices normally\n   appear. The contents of the NOTICE file are for informational purposes only\n   and do not modify the License. You may add Your own attribution notices\n   within Derivative Works that You distribute, alongside or as an addendum to\n   the NOTICE text from the Work, provided that such additional attribution\n   notices cannot be construed as modifying the License.\n\nYou may add Your own copyright statement to Your modifications and may provide\nadditional or different license terms and conditions for use, reproduction, or\ndistribution of Your modifications, or for any such Derivative Works as a whole,\nprovided Your use, reproduction, and distribution of the Work otherwise complies\nwith the conditions stated in this License.","ref":"license.html#4-redistribution"},{"type":"extras","title":"5. Submission of Contributions. - License","doc":"Unless You explicitly state otherwise, any Contribution intentionally submitted\nfor inclusion in the Work by You to the Licensor shall be under the terms and\nconditions of this License, without any additional terms or conditions.\nNotwithstanding the above, nothing herein shall supersede or modify the terms of\nany separate license agreement you may have executed with Licensor regarding\nsuch Contributions.","ref":"license.html#5-submission-of-contributions"},{"type":"extras","title":"6. Trademarks. - License","doc":"This License does not grant permission to use the trade names, trademarks,\nservice marks, or product names of the Licensor, except as required for\nreasonable and customary use in describing the origin of the Work and\nreproducing the content of the NOTICE file.","ref":"license.html#6-trademarks"},{"type":"extras","title":"7. Disclaimer of Warranty. - License","doc":"Unless required by applicable law or agreed to in writing, Licensor provides the\nWork (and each Contributor provides its Contributions) on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied,\nincluding, without limitation, any warranties or conditions of TITLE, NON-\nINFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are\nsolely responsible for determining the appropriateness of using or\nredistributing the Work and assume any risks associated with Your exercise of\npermissions under this License.","ref":"license.html#7-disclaimer-of-warranty"},{"type":"extras","title":"8. Limitation of Liability. - License","doc":"In no event and under no legal theory, whether in tort (including negligence),\ncontract, or otherwise, unless required by applicable law (such as deliberate\nand grossly negligent acts) or agreed to in writing, shall any Contributor be\nliable to You for damages, including any direct, indirect, special, incidental,\nor consequential damages of any character arising as a result of this License or\nout of the use or inability to use the Work (including but not limited to\ndamages for loss of goodwill, work stoppage, computer failure or malfunction, or\nany and all other commercial damages or losses), even if such Contributor has\nbeen advised of the possibility of such damages.","ref":"license.html#8-limitation-of-liability"},{"type":"extras","title":"9. Accepting Warranty or Additional Liability. - License","doc":"While redistributing the Work or Derivative Works thereof, You may choose to\noffer, and charge a fee for, acceptance of support, warranty, indemnity, or\nother liability obligations and/or rights consistent with this License. However,\nin accepting such obligations, You may act only on Your own behalf and on Your\nsole responsibility, not on behalf of any other Contributor, and only if You\nagree to indemnify, defend, and hold each Contributor harmless for any liability\nincurred by, or claims asserted against, such Contributor by reason of your\naccepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS","ref":"license.html#9-accepting-warranty-or-additional-liability"},{"type":"extras","title":"Overview","doc":"# PasswordValidator\n\n[![Module Version](https://img.shields.io/hexpm/v/password_validator.svg)](https://hex.pm/packages/password_validator)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/password_validator/)\n[![Total Download](https://img.shields.io/hexpm/dt/password_validator.svg)](https://hex.pm/packages/password_validator)\n[![License](https://img.shields.io/hexpm/l/password-validator.svg)](https://github.com/axelson/password-validator/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/axelson/password-validator.svg)](https://github.com/axelson/password-validator/commits/master)\n\nPasswordValidator is a library to validate passwords, makes sense doesn't it? By\ndefault two validators are built in, but it is also possible to create your own\ncustom validator for more advanced usage.\n\nValidators:\n* LengthValidator - validates the length of the password\n* CharacterSetValidator - validates the characters contained within the\n  password, number of lower case, number of upper case, number of special\n  characters, etc.\n* [ZXCVBNValidator](https://github.com/axelson/password-validator-zxcvbn) - Uses\n  Dropbox's [zxcvbn](https://github.com/dropbox/zxcvbn) algorithm to rate\n  passwords\n\nThe primary use case is validating an `%Ecto.Changeset{}`","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"`PasswordValidator` is [available in Hex](https://hex.pm/packages/password_validator), the package can be installed\nby adding `password_validator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:password_validator, \"~> 0.5\"},\n  ]\nend\n```\n\nThe docs can be found at [https://hexdocs.pm/password_validator](https://hexdocs.pm/password_validator).","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"PasswordValidator will typically be used within the changeset function of an Ecto schema:\n\n``` elixir\n@password_opts [\n  length: [min: 7, max: 30, messages: [too_short: \"Password is too short!\"]],\n  character_set: [\n    lower_case: 5,  # at least five lower case letters\n    upper_case: [3, :infinity], # at least three upper case letters\n    numbers: [1, 4],  # from 1 to 4 number characters\n    special: [0, 0],  # no special characters allowed\n  ]\n]\n\ndef changeset(user, attrs) do\n  user\n  |> cast(attrs, [:name, :age, :password])\n  |> validate_required([:name, :age, :password])\n  # Add this to your changeset\n  |> PasswordValidator.validate(:password, @password_opts)\nend\n```\n\nExample interactive usage:\n\n``` elixir\niex> opts = [\n...>   length: [min: 12, max: 30],\n...> ]\niex> changeset = Ecto.Changeset.change({%{password: \"simple_pass\"}, %{}}, %{})\n#Ecto.Changeset \niex> PasswordValidator.validate(changeset, :password, opts)\n#Ecto.Changeset \n```\n\nFull example:\n``` elixir\niex> opts = [\n...>   length: [min: 5, max: 30],\n...>   character_set: [\n...>     lower_case: 1,  # at least one lower case letter\n...>     upper_case: [3, :infinity], # at least three upper case letters\n...>     numbers: [0, 4],  # at most 4 numbers\n...>     special: [0, 0],  # no special characters allowed\n...>   ]\n...> ]\niex> changeset = Ecto.Changeset.change({%{password: \"Simple_pass12345\"}, %{}}, %{})\niex> changeset = PasswordValidator.validate(changeset, :password, opts)\niex> changeset.errors\n[password: {\"Too many special (1 but maximum is 0)\", [\n  {:validator, PasswordValidator.Validators.CharacterSetValidator},\n  {:error_type, :too_many_special}\n]},\npassword: {\"Too many numbers (5 but maximum is 4)\", [\n  {:validator, PasswordValidator.Validators.CharacterSetValidator},\n  {:error_type, :too_many_numbers}\n]},\npassword: {\"Not enough upper_case characters (only 1 instead of at least 3)\", [\n  {:validator, PasswordValidator.Validators.CharacterSetValidator},\n  {:error_type, :too_few_upper_case}\n]}]\n```\n\nIf you want to check that a PasswordValidator error was added then in the changeset's errors field you can check that there is an error with the key `:validator`\n\nPasswordValidator can also be run directly on a String:\n\n```\niex> opts = [\n...>   length: [max: 6],\n...> ]\niex> PasswordValidator.validate_password(\"too_long\", opts)\n{:error, [\"String is too long. 8 but maximum is 6\"]}\n```\n\nNote: The `CharacterSetValidator` set of allowed special characters defaults to\nany character that is not lower case, upper case, or a number. If the\n`CharacterSetValidator` is passed `allowed_special_characters` (as a string)\nthen just those characters will be considered as special characters and any\nother characters will be considered \"other\" and will fail the password check.\nFor full details see the `CharacterSetValidator` docs.\n\nNote: On an invalid configuration the library will raise an error.","ref":"readme.html#usage"},{"type":"extras","title":"Custom validators - Overview","doc":"Custom Validators need to implement the `PasswordValidator.Validator` behaviour.\nCurrently the only callback is `validate`. They can then be supplied as options (to either `PasswordValidator.validate/3` or `PasswordValidator.validate_password/2`)","ref":"readme.html#custom-validators"},{"type":"extras","title":"Constraints - Overview","doc":"* Doesn't deal well with non-latin characters\n* Currently always pulls in Ecto as a dependency","ref":"readme.html#constraints"},{"type":"extras","title":"Contributing - Overview","doc":"To run the default test suite, run `mix test`\n\nPR's and discussions welcome!","ref":"readme.html#contributing"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2017 Jason Axelson\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#copyright-and-license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}